summaryrefslogtreecommitdiffstats
path: root/kbabel/datatools/length/main.cc
diff options
context:
space:
mode:
Diffstat (limited to 'kbabel/datatools/length/main.cc')
-rw-r--r--kbabel/datatools/length/main.cc6
1 files changed, 3 insertions, 3 deletions
diff --git a/kbabel/datatools/length/main.cc b/kbabel/datatools/length/main.cc
index 2851429e..706cf10c 100644
--- a/kbabel/datatools/length/main.cc
+++ b/kbabel/datatools/length/main.cc
@@ -104,7 +104,7 @@ bool LengthTool::run( const TQString& command, void* data, const TQString& datat
if( item->pluralForm() == KDESpecific ) {
str = TQStringList::split( "\\n", item->msgstr().first(), true );
id = TQStringList::split( "\\n",
- item->msgid().first().tqreplace( TQRegExp(_plurals), ""), true );
+ item->msgid().first().replace( TQRegExp(_plurals), ""), true );
} else {
str = item->msgstr();
id = item->msgid();
@@ -113,12 +113,12 @@ bool LengthTool::run( const TQString& command, void* data, const TQString& datat
//Check for translations that are too short or too long
//This may not be totally correct but we check both
//the singular and plural forms against each translated plural.
//FIXME: tqreplace 10% check with configurable setting or a statistical
//based expected length relationship
int idlen, strlen;
for( TQStringList::Iterator i = id.begin() ; i != id.end() ; i++ ) {
TQString iditem = (*i);
- idlen = iditem.tqreplace( TQRegExp(_context),"").length();
+ idlen = iditem.replace( TQRegExp(_context),"").length();
for( TQStringList::Iterator j = str.begin() ; j != str.end() ; j++ ) {
TQString stritem = (*j);
strlen = stritem.length();
@@ -113,12 +113,12 @@ bool LengthTool::run( const TQString& command, void* data, const TQString& datat
//This may not be totally correct but we check both
//the singular and plural forms against each translated plural.
- //FIXME: tqreplace 10% check with configurable setting or a statistical
+ //FIXME: replace 10% check with configurable setting or a statistical
//based expected length relationship
int idlen, strlen;